function out = splitstep(tspan,psi,h_phi,a,v,alpha,nmax)
    dt = .1;                                % Time step
    tfinal = tspan(2);                      % Final time
    M = round(tfinal/dt);                   % Total number of time steps
    %nmax = 7;                               % Which Bloch harmonics to use (from -nmax to nmax)
    N = (2*nmax+1);                         % Total number of harmonics
    %alpha = 10/32;                          % Strength of the lattice
    acc = @(t)-1*a*t.^2/2;                  % Acceleration that the system is undergoing
    n = ( -nmax:nmax)';                     % Indices
    u = ifftshift(psi);                     % Duplicate of the state for propagating
    k = ifftshift(n);                       % Momentum space grid
    x = 2*pi/N*(0:N-1)';                    % Position space grid
    eta = @(t)Split(t,v,tfinal);                     % Accelerating potential to split the lattices
    optical_potential = @(t)2*alpha*cos(eta(t))*cos(x+h_phi(t)+acc(t)); % Potential
    
    out=NaN(2*nmax+1,M);
    for m = 1:M
        c = exp(dt/2*-1i/2*k.^2).*u;
        u = N*ifft(c);
        u = exp(dt*-1i*optical_potential(dt*(m-1)+dt/2)).*u;
        c = fft(u)/N;
        u = exp(dt/2*-1i/2*k.^2).*c;
        out(:,m) = fftshift(u);
    end
end